@@ -8,9 +8,11 @@ import torch as pt
 from torch.utils.data import IterableDataset
 
 class TensorIterable(IterableDataset):
-    def __init__(self, osds, dtype = pt.float32):
+    def __init__(self, osds, dtype = pt.float32, max_iter = None):
         self.iter = iter(osds)
         self.dtype = dtype
+        self.max_iter = max_iter
+
     def __iter__(self):        
         val = next(self.iter)
         while val is not None:
@@ -20,6 +22,12 @@ class TensorIterable(IterableDataset):
             except ValueError as err:
                 raise ValueError(f"Failed data type conversion, use ObjectStorageDataset(header='infer') if the dataset has a header:  {err}")
 
+    def __len__(self):
+        if self.max_iter is None:
+            return None
+        else:
+            return self.max_iter
+
 def make_metadata_df(glob = None, df = None):    
     assert glob is not None or df is not None, "Either glob or df must be specified"
     df = pd.read_csv(glob) if glob else df
